define((function () { 'use strict';

	for(var x=1;x<2;x++)var d=x|0;console.log(d);

}));
